@@ -5,13 +5,17 @@ import json
 
 
 def load_json(path):
+    """
+    Load JSON encoded file and return its contents.
+    """
     with open(path, "r") as src:
         content = json.load(src)
 
     return content
 
 
-def next_best_specification_source(fallback, app_name=None, root_path=None):
+def next_best_specification_source(fallback, app_name=None, root_path=None,
+                                   trunk=None):
     """
     Determine the best matching wolfication specification for *app_name*.
 
@@ -19,6 +23,7 @@ def next_best_specification_source(fallback, app_name=None, root_path=None):
         fallback: fallback source name
         app_name (unicode, optional): application name
         root_path (unicode, optional): path where specification files may be located
+        trunk (unicode, optional): specification file trunk
 
     Returns:
         unicode: specification path
@@ -28,19 +33,22 @@ def next_best_specification_source(fallback, app_name=None, root_path=None):
     if root_path is None:
         root_path = os.path.dirname(fallback)
 
+    if trunk is None:
+        trunk = 'wolfication_specification'
+
     if app_name:
         candidates.append(
             os.path.join(
                 root_path,
-                'wolfication_specification.{app_name}.json'.format(
-                    app_name=app_name)
+                '{trunk}.{app_name}.json'.format(
+                    app_name=app_name, trunk=trunk)
             )
         )
 
     candidates.append(
         os.path.join(
             root_path,
-            'wolfication_specification.json'
+            '{trunk}.json'.format(trunk=trunk)
         )
     )
 
@@ -49,3 +57,19 @@ def next_best_specification_source(fallback, app_name=None, root_path=None):
             return os.path.abspath(candy)
 
     return fallback
+
+
+def next_best_asset_source(fallback, app_name=None, root_path=None):
+    """
+    Determine the best matching wolfication index for *app_name*.
+
+    Args:
+        fallback: fallback source name
+        app_name (unicode, optional): application name
+        root_path (unicode, optional): path where specification files may be located
+
+    Returns:
+        unicode: index path
+    """
+    return next_best_specification_source(fallback, app_name=app_name,
+                                          root_path=root_path, trunk="index")
